package org.greenstone.gatherer.gui;
/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.Configuration;
/** Displays a dynamic prompt to allow the user to choose how metadata is to be added, updated or removed from target FileNodes. The prompt changes depending on the action requested, the file nodes encountered and the number of file nodes in the selection. */
public class MetaEditPrompt
	 extends JDialog 
	 implements ActionListener {

	 private boolean multiple_selection = false;

	 private int type;
	 private int value;

	 private JButton accumulate_b;
	 private JButton accumulate_all_b;
	 private JButton cancel_b;
	 private JButton skip_b;
	 private JButton overwrite_b;
	 private JButton overwrite_all_b;
	 private JButton remove_b;
	 private JButton remove_all_b;
	 private JButton update_b;
	 private JButton update_all_b;

	 private JLabel title;

	 private JTextArea text;

	 private JPanel button_row;
	 private JPanel content_pane;

	 static private Dimension SIZE    = new Dimension(400, 280);

	 // Prompt Types
	 static public int ADD_PROMPT      =  0;
	 static public int REMOVE_PROMPT   =  1;
	 static public int UPDATE_PROMPT   =  2;

	 // Generic prompt values.
	 static public int CONFIRM         =  0;
	 static public int CANCEL          =  1;
	 static public int SKIP            =  2;

	 // Values for the different add action prompts.
	 static public int ACCUMULATE      =  3;
	 static public int ACCUMULATE_ALL  =  4;
	 static public int OVERWRITE       =  5;
	 static public int OVERWRITE_ALL   =  6;

	 // Values for the different update action prompts.
	 static public int UPDATE          =  7;
	 static public int UPDATE_ALL      =  8;
	 static public int UPDATE_ONCE     =  9;

	 // Values for the different remove action prompts.
	 static public int REMOVE          = 10;
	 static public int REMOVE_ALL      = 11;

	 public MetaEditPrompt(int type, boolean multiple_selection) {
		  super(Gatherer.g_man); // Needed for modal response!
		  this.multiple_selection = multiple_selection;
		  this.setFont(Gatherer.config.getFont("general.font", false));
		  this.setModal(true);
		  this.setSize(SIZE);
		  this.type = type;
		  if(type == ADD_PROMPT) {
				this.setTitle(get("Add_Title"));
				title = new JLabel(get("Add_Title"));
		  }
		  else if(type == REMOVE_PROMPT) {
				this.setTitle(get("Remove_Title"));
				title = new JLabel(get("Remove_Title"));
		  }
		  else {
				this.setTitle(get("Update_Title"));
				title = new JLabel(get("Update_Title"));
		  }
		  title.setOpaque(false);

		  content_pane = (JPanel)this.getContentPane();
		  content_pane.setBackground(Gatherer.config.getColor("coloring.collection_heading_background", false));
		  content_pane.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));

		  // Set up some preset components.
		  text = new JTextArea();
		  text.setBackground(Gatherer.config.getColor("coloring.collection_tree_background", false));
		  text.setEditable(false);

		  button_row = new JPanel();
		  button_row.setOpaque(false);

		  accumulate_b = new JButton(get("Accumulate"));
		  accumulate_b.addActionListener(this);
		  accumulate_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  accumulate_b.setMnemonic(KeyEvent.VK_A);

		  accumulate_all_b = new JButton(get("Accumulate_All"));
		  accumulate_all_b.addActionListener(this);
		  accumulate_all_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  accumulate_all_b.setMnemonic(KeyEvent.VK_D);

		  cancel_b = new JButton(get("Cancel"));
		  cancel_b.addActionListener(this);
		  cancel_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  cancel_b.setMnemonic(KeyEvent.VK_C);

		  skip_b = new JButton(get("Skip"));
		  skip_b.addActionListener(this);
		  skip_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  skip_b.setMnemonic(KeyEvent.VK_S);

		  overwrite_b = new JButton(get("Overwrite"));
		  overwrite_b.addActionListener(this);
		  overwrite_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  overwrite_b.setMnemonic(KeyEvent.VK_R);

		  overwrite_all_b = new JButton(get("Overwrite_All"));
		  overwrite_all_b.addActionListener(this);
		  overwrite_all_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  overwrite_all_b.setMnemonic(KeyEvent.VK_E);

		  remove_b = new JButton(get("Remove"));
		  remove_b.addActionListener(this);
		  remove_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  remove_b.setMnemonic(KeyEvent.VK_R);

		  remove_all_b = new JButton(get("Remove_All"));
		  remove_all_b.addActionListener(this);
		  remove_all_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  remove_all_b.setMnemonic(KeyEvent.VK_A);

		  update_b = new JButton(get("Update"));
		  update_b.addActionListener(this);
		  update_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  update_b.setMnemonic(KeyEvent.VK_U);

		  update_all_b = new JButton(get("Update_All"));
		  update_all_b.addActionListener(this);
		  update_all_b.setBackground(Gatherer.config.getColor("coloring.button_background", false));
		  update_all_b.setMnemonic(KeyEvent.VK_A);
	 }

	 public void actionPerformed(ActionEvent event) {
		  Object esrc = event.getSource();
		  if(esrc == accumulate_b) {
				value = ACCUMULATE;
		  }
		  else if(esrc == accumulate_all_b) {
				value = ACCUMULATE_ALL;
		  }
		  else if(esrc == cancel_b) {
				value = CANCEL;
		  }
		  else if(esrc == skip_b) {
				value = SKIP;
		  }		  
		  else if(esrc == overwrite_b) {
				value = OVERWRITE;
		  }
		  else if(esrc == overwrite_all_b) {
				value = OVERWRITE_ALL;
		  }
		  else if(esrc == remove_b) {
				value = REMOVE;
		  }
		  else if(esrc == remove_all_b) {
				value = REMOVE_ALL;
		  }
		  else if(esrc == update_b) {
				value = UPDATE;
		  }
		  else if(esrc == update_all_b) {
				value = UPDATE_ALL;
		  }
		  this.dispose();
	 }

	 public int display(String f, String k, String v) {
		  String args[] = new String[1];

		  content_pane.setLayout(new BorderLayout());

		  content_pane.add(title, BorderLayout.NORTH);

		  JPanel middle_pane = new JPanel(new BorderLayout());
		  middle_pane.setOpaque(false);
		  middle_pane.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(5,5,5,5), BorderFactory.createLoweredBevelBorder()));

		  args[0] = f;
		  text.append(get("File", args));
		  text.append("\n");
		  args[0] = k;
		  text.append(get("Key", args));
		  text.append("\n");
		  args[0] = v;
		  text.append(get("Value", args));
		  text.append("\n");
		  
		  button_row.setLayout(new GridLayout(4,1,2,2));

		  // Add the components
		  middle_pane.add(new JScrollPane(text), BorderLayout.CENTER);

		  button_row.add(remove_b);
		  if(multiple_selection) {
				button_row.add(remove_all_b);
		  }
		  else {
				button_row.add(new JPanel());
		  }
		  button_row.add(skip_b);
		  button_row.add(cancel_b);

		  content_pane.add(title, BorderLayout.NORTH);
		  content_pane.add(middle_pane, BorderLayout.CENTER);
		  content_pane.add(button_row, BorderLayout.SOUTH);

		  text.setCaretPosition(0);

		  Rectangle frame_bounds = Gatherer.g_man.getBounds();
		  this.setLocation(frame_bounds.x + ((frame_bounds.width - SIZE.width) / 2), frame_bounds.y + ((frame_bounds.height - SIZE.height) / 2));
		  show();
		  return value;
	 }

	 public int display(String f, String k, String o_v, String n_v) {
		  String args[] = new String[1];
		  
		  content_pane.setLayout(new BorderLayout());
		  
		  content_pane.add(title, BorderLayout.NORTH);
		  
		  JPanel middle_pane = new JPanel(new BorderLayout());
		  middle_pane.setOpaque(false);
		  middle_pane.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(5,5,5,5), BorderFactory.createLoweredBevelBorder()));
		  		  
		  args[0] = f;
		  text.append(get("File", args));
		  text.append("\n");
		  args[0] = k;
		  text.append(get("Key", args));
		  text.append("\n");
		  args[0] = o_v;
		  text.append(get("Old_Value", args));
		  text.append("\n");
		  args[0] = n_v;
		  text.append(get("New_Value", args));
		  text.append("\n");

		  if(type == ADD_PROMPT) {
				button_row.setLayout(new GridLayout(3,2,2,2));
		  }
		  else {
				button_row.setLayout(new GridLayout(2,2,2,2));
		  }
		  
		  // Add the components
		  middle_pane.add(new JScrollPane(text), BorderLayout.CENTER);

		  if(type == ADD_PROMPT) {
				button_row.add(accumulate_b);
				if(multiple_selection) {
					 button_row.add(accumulate_all_b);
				}
				else {
					 button_row.add(new JPanel());
				}
				button_row.add(overwrite_b);
				if(multiple_selection) {
					 button_row.add(overwrite_all_b);
				}
				else {
					 button_row.add(new JPanel());
				}
				button_row.add(skip_b);
				button_row.add(cancel_b);
		  }
		  else {
				button_row.add(update_b);
				if(multiple_selection) {
					 button_row.add(update_all_b);
				}
				else {
					 button_row.add(new JPanel());
				}
				button_row.add(skip_b);
				button_row.add(cancel_b);
		  }

		  content_pane.add(title, BorderLayout.NORTH);
		  content_pane.add(middle_pane, BorderLayout.CENTER);
		  content_pane.add(button_row, BorderLayout.SOUTH);

		  text.setCaretPosition(0);

		  Rectangle frame_bounds = Gatherer.g_man.getBounds();
		  this.setLocation(frame_bounds.x + ((frame_bounds.width - SIZE.width) / 2), frame_bounds.y + ((frame_bounds.height - SIZE.height) / 2));
		  show();
		  return value;
	 }

	 private String get(String key) {
		  return get(key, null);
	 }

	 private String get(String key, String args[]) {
		  if(key.indexOf(".") == -1) {
				key = "MetaEditPrompt." + key;
		  }
		  return Gatherer.dictionary.get(key, args);
	 }
}
